@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -34,7 +34,7 @@ namespace Ui {
 }
 
 /** Dialog class for executing Command objects. */
-class ActionDialog : public QDialog {
+class ActionDialog final : public QDialog {
     Q_OBJECT
 public:
     explicit ActionDialog(QWidget *parent = nullptr);
