@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -30,7 +30,7 @@ class AddCommandDialog;
 class QSortFilterProxyModel;
 struct Command;
 
-class AddCommandDialog : public QDialog
+class AddCommandDialog final : public QDialog
 {
     Q_OBJECT
 
