@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>
+    Copyright (c) 2019, Lukas Holecek <hluk@email.cz>
 
     This file is part of CopyQ.
 
@@ -34,7 +34,7 @@ namespace Ui {
     class ClipboardDialog;
 }
 
-class ClipboardDialog : public QDialog
+class ClipboardDialog final : public QDialog
 {
     Q_OBJECT
 
@@ -72,6 +72,7 @@ private:
     QPointer<QAbstractItemModel> m_model;
     QPersistentModelIndex m_index;
     QVariantMap m_data;
+    bool m_dataFromClipboard = false;
     QString m_textToShow;
     QTimer m_timerTextLoad;
 
