@@ -255,6 +255,7 @@ public slots:
     void keys();
     QScriptValue testSelected();
     void serverLog();
+    QScriptValue logs();
 
     void setCurrentTab();
 
@@ -370,6 +371,8 @@ public slots:
     void provideClipboard();
     void provideSelection();
 
+    QScriptValue clipboardFormatsToSave();
+
 signals:
     void finished();
 
@@ -395,6 +398,7 @@ private:
     bool runCommands(CommandType::CommandType type);
     bool canExecuteCommand(const Command &command);
     bool canExecuteCommandFilter(const QString &matchCommand);
+    bool canAccessClipboard() const;
     bool verifyClipboardAccess();
     void provideClipboard(ClipboardMode mode);
 
@@ -409,6 +413,9 @@ private:
     void getActionData();
     void setActionData();
 
+    QByteArray getClipboardData(const QString &mime, ClipboardMode mode = ClipboardMode::Clipboard);
+    bool hasClipboardFormat(const QString &mime, ClipboardMode mode = ClipboardMode::Clipboard);
+
     void synchronizeSelection(ClipboardMode targetMode);
 
     void saveData(const QString &tab);
