@@ -44,6 +44,7 @@ private slots:
     void init();
     void cleanup();
 
+    void readLog();
     void commandHelp();
     void commandVersion();
     void badCommand();
@@ -137,6 +138,8 @@ private slots:
     void commandUnload();
     void commandForceUnload();
 
+    void commandServerLogAndLogs();
+
     void classByteArray();
     void classFile();
     void classDir();
